@@ -186,7 +186,7 @@ public class ConnectionPool {
     public void destroy() {
         for ( int i = 0; i < pool.size(); i++ ) {
             disconnect(
-                (LDAPConnectionObject)pool.elementAt(i) );
+                pool.elementAt(i) );
         }
         pool.removeAllElements();
     }
@@ -272,7 +272,7 @@ public class ConnectionPool {
 
             // Get the ConnectionObject from the pool
             LDAPConnectionObject co =
-                (LDAPConnectionObject)pool.elementAt(i);
+                pool.elementAt(i);
 
             if ( co.isAvailable() ) {  // Conn available?
                 ldapconnobj = co;
@@ -293,7 +293,7 @@ public class ConnectionPool {
                 // If a new connection was created, use it
                 if ( i >= 0 ) {
                     ldapconnobj =
-                        (LDAPConnectionObject)pool.elementAt(i);
+                        pool.elementAt(i);
                 }
             } else {
                 debug("All pool connections in use");
@@ -320,7 +320,7 @@ public class ConnectionPool {
         int index = find( ld );
         if ( index != -1 ) {
             LDAPConnectionObject co =
-                (LDAPConnectionObject)pool.elementAt(index);
+                pool.elementAt(index);
 
             // Reset the auth if necessary
             if (ldc == null || !ldc.getAuthenticationMethod().equals("sasl")) {
@@ -358,7 +358,7 @@ public class ConnectionPool {
         System.out.println("--ConnectionPool--");
         for ( int i = 0; i < pool.size(); i++ ) {
             LDAPConnectionObject co =
-                (LDAPConnectionObject)pool.elementAt(i);
+                pool.elementAt(i);
             System.out.println( "" + i + "=" + co );
         }
     }
@@ -397,7 +397,7 @@ public class ConnectionPool {
         debug("Maximum number of connections="+poolMax);
         debug("******");
 
-        pool = new java.util.Vector(); // Create pool vector
+        pool = new java.util.Vector<>(); // Create pool vector
         setUpPool( poolSize ); // Initialize it
     }
 
@@ -443,7 +443,7 @@ public class ConnectionPool {
                     }
                     catch (LDAPException connEx) {
                         // fallback to ldap v2 if v3 is not supported
-                        if (connEx.getLDAPResultCode() == connEx.PROTOCOL_ERROR) {
+                        if (connEx.getLDAPResultCode() == LDAPException.PROTOCOL_ERROR) {
                             newConn.connect( 2, host, port, authdn, authpw);
                         }
                         else {
@@ -466,7 +466,7 @@ public class ConnectionPool {
         if ( con != null ) {
             for ( int i = 0; i < pool.size(); i++ ) {
                 LDAPConnectionObject co =
-                    (LDAPConnectionObject)pool.elementAt(i);
+                    pool.elementAt(i);
                 if ( co.getLDAPConn() == con ) {
                     return i;
                 }
@@ -571,6 +571,6 @@ public class ConnectionPool {
     private String authdn;  // Identity of connections
     private String authpw;  // Password for authdn
     private LDAPConnection ldc = null; // Connection to clone
-    private java.util.Vector pool;  // the actual pool
+    private java.util.Vector<LDAPConnectionObject> pool;  // the actual pool
     private boolean debugMode;
 }
